@@ -1,13 +1,13 @@
 package Facebook::Graph::Publish;
 BEGIN {
-  $Facebook::Graph::Publish::VERSION = '1.0301';
+  $Facebook::Graph::Publish::VERSION = '1.0400';
 }
 
 use Any::Moose;
 use Facebook::Graph::Response;
 with 'Facebook::Graph::Role::Uri';
 use LWP::UserAgent;
-use URI::Encode qw(uri_decode);
+use URI::Escape;
 
 has secret => (
     is          => 'ro',
@@ -39,7 +39,7 @@ sub get_post_params {
     my $self = shift;
     my @post;
     if ($self->has_access_token) {
-        push @post, access_token => uri_decode($self->access_token);
+        push @post, access_token => uri_unescape($self->access_token);
     }
     return \@post;
 }
@@ -66,7 +66,7 @@ Facebook::Graph::Publish - A base class for publishing various things to faceboo
 
 =head1 VERSION
 
-version 1.0301
+version 1.0400
 
 =head1 DESCRIPTION
 
