@@ -1,13 +1,13 @@
 package Facebook::Graph::Query;
 BEGIN {
-  $Facebook::Graph::Query::VERSION = '1.0301';
+  $Facebook::Graph::Query::VERSION = '1.0400';
 }
 
 use Any::Moose;
 use Facebook::Graph::Response;
 with 'Facebook::Graph::Role::Uri';
 use LWP::UserAgent;
-use URI::Encode qw(uri_decode);
+use URI::Escape;
 
 has secret => (
     is          => 'ro',
@@ -49,6 +49,12 @@ has offset => (
     predicate   => 'has_offset',
 );
 
+has datef => (
+    is          => 'rw',
+    predicate   => 'has_datef',
+);
+
+
 has search_query => (
     is          => 'rw',
     predicate   => 'has_search_query',
@@ -84,6 +90,12 @@ sub limit_results {
     return $self;    
 }
 
+sub date_format {
+    my ($self, $date_format) = @_;
+    $self->datef($date_format);
+    return $self;
+}
+
 sub find {
     my ($self, $object_name) = @_;
     $self->object_name($object_name);
@@ -149,7 +161,7 @@ sub uri_as_string {
     my ($self) = @_;
     my %query;
     if ($self->has_access_token) {
-        $query{access_token} = uri_decode($self->access_token);
+        $query{access_token} = uri_unescape($self->access_token);
     }
     if ($self->has_limit) {
         $query{limit} = $self->limit;
@@ -157,6 +169,9 @@ sub uri_as_string {
             $query{offset} = $self->offset;
         }
     }
+    if ($self->has_datef) {
+        $query{date_format} = $self->datef;
+    }
     if ($self->has_search_query) {
         $query{q} = $self->search_query;
         if ($self->has_search_type) {
@@ -205,7 +220,7 @@ Facebook::Graph::Query - Simple and fast searching and fetching of Facebook data
 
 =head1 VERSION
 
-version 1.0301
+version 1.0400
 
 =head1 SYNOPSIS
 
@@ -227,6 +242,7 @@ version 1.0301
     ->where_since('1 January 2011')
     ->where_until('2 January 2011')
     ->limit(25)
+    ->date_format('U')
     ->request
     ->as_hashref;
 
@@ -329,6 +345,10 @@ See the C<context> param in the C<from> method.
 
 The result set will only return a certain number of records when this is set. Useful for paging result sets. Returns C<$self> for method chaining.
 
+=head2 date_format ( format )
+
+The result set dates will be formated in the defined formats.  Specify the format by reference the PHP date format spec: L<http://php.net/manual/en/function.date.php>. (eg. ->date_format('U')->) Useful for getting epoch for datatime. Returns C<$self> for method chaining.
+
 =head3 amount
 
 An integer representing the number of records to be returned.
